==> smooch_plugin-2.0.31.tar.gz: android/src/main/kotlin/io/skore/smooch_plugin/util/Res.kt <==
package io.skore.smooch_plugin.util

import android.content.Context
import android.content.SharedPreferences
import android.content.res.Resources
import android.graphics.Color
import io.skore.smooch_plugin.view.CHAT_COLOR
import io.skore.smooch_plugin.view.SHARED_PREFERENCES

class Res(original: Resources, context: Context) : Resources(original.assets, original.displayMetrics, original.configuration) {
    private var sharedPreferences: SharedPreferences? = null
    private var chatColor: Int? = null

    init {
        sharedPreferences = context.getSharedPreferences(SHARED_PREFERENCES, Context.MODE_PRIVATE)
        this.chatColor = sharedPreferences?.getString(CHAT_COLOR, null)?.let { Color.parseColor(it) }
    }

    @Throws(NotFoundException::class)
    override fun getColor(id: Int): Int {
        return getColor(id, null)
    }

    @Throws(NotFoundException::class)
    override fun getColor(id: Int, theme: Theme?): Int {
        return when (getResourceEntryName(id)) {
            "skore_yellow" -> this.chatColor
            "Smooch_accent" -> this.chatColor
            "Smooch_accentLight" -> this.chatColor
            "Smooch_accentDark" -> this.chatColor
            "Smooch_accentFailure" -> this.chatColor
//            "Smooch_remoteMessageBackground" -> Color.RED
            "Smooch_userMessageBackground" -> this.chatColor
//            "Smooch_remoteMessageText" -> Color.BLUE
//            "Smooch_userMessageText" -> Color.BLUE
            "colorAccent" -> this.chatColor
            "white" -> this.chatColor
            else -> null
        } ?: super.getColor(id, theme)
    }
}

==> smooch_plugin-2.0.49.tar.gz: android/src/main/kotlin/io/skore/smooch_plugin/util/Res.kt <==
package io.skore.smooch_plugin.util

import android.content.Context
import android.content.SharedPreferences
import android.content.res.Resources
import android.graphics.Color
import androidx.core.content.res.ResourcesCompat
import io.skore.smooch_plugin.view.CHAT_COLOR
import io.skore.smooch_plugin.view.SHARED_PREFERENCES

class Res(private val original: Resources, context: Context) : Resources(original.assets, original.displayMetrics, original.configuration) {
    private var sharedPreferences: SharedPreferences? = null
    private var chatColor: Int? = null

    init {
        sharedPreferences = context.getSharedPreferences(SHARED_PREFERENCES, Context.MODE_PRIVATE)
        this.chatColor = sharedPreferences?.getString(CHAT_COLOR, null)?.let { Color.parseColor(it) }
    }

    @Throws(NotFoundException::class)
    override fun getColor(id: Int): Int {
        return getColor(id, null)
    }

    @Throws(NotFoundException::class)
    override fun getColor(id: Int, theme: Theme?): Int {
        return when (getResourceEntryName(id)) {
            "skore_yellow" -> this.chatColor
            "Smooch_accent" -> this.chatColor
            "Smooch_accentLight" -> this.chatColor
            "Smooch_accentDark" -> this.chatColor
            "Smooch_accentFailure" -> this.chatColor
            "Smooch_userMessageBackground" -> this.chatColor
            "colorAccent" -> this.chatColor
            "white" -> this.chatColor
            else -> null
        } ?: ResourcesCompat.getColor(original, id, theme)
    }
}
